const mongoose = require("mongoose");

const notificationSchema = new mongoose.Schema(
  {
    user: {
      type: mongoose.Schema.Types.ObjectId,
      ref: "User", // Reference to the User model
      required: true,
    },
    message: {
      type: String,
      required: [true, "Notification message is required"],
    },
    type: {
      type: String,
      enum: ["connection", "like", "comment", "message", "other"], // Types of notifications
      required: true,
    },
    link: {
      type: String, // Optional link to navigate when notification is clicked
    },
    status: {
      type: String,
      enum: ["unread", "read"], // Status of the notification
      default: "unread",
    },
    createdAt: {
      type: Date,
      default: Date.now,
    },
  },
  { timestamps: true }
);

// Pre-save hook to ensure that the status is 'unread' when a new notification is created
notificationSchema.pre("save", function (next) {
  if (!this.status) {
    this.status = "unread"; // Default to 'unread' status
  }
  next();
});

const Notification = mongoose.model("Notification", notificationSchema);

module.exports = Notification;
