const express = require("express");
const authController = require("./../controllers/authController");
const userController = require("../controllers/userController");

const router = express.Router();

// **Protected Routes** (require authentication)

router.use(authController.protect); // Protect all routes below this middleware

//Get Current User LoggedIn
router.get("/current-user", userController.getCurrentUserProfile);

// Get All Users
router.get("/all-users", userController.getAllUsers);

// Get Suggested Users based on current user's interests
router.get("/get-suggested-users", userController.getSuggestedUsers);
// Route to check profile visibility status
router.get(
  "/check-profile-visibility",
  authController.protect,
  userController.checkProfileVisibility
);

// Get user by ID
router.get("/:id", userController.getUserById);

// Route to update the profile picture
router.patch("/profile-picture", userController.updateProfilePicture);

// Route to update bio and social links
router.patch("/update-profile/bio-links", userController.updateProfileBioLink);

// Route to update the current user's profile
router.put(
  "/update-profile/edit-info",
  userController.updateCurrentUserProfile
);

// Route to get the current user's profile completion percentage
router.get("/profile/completion", userController.getProfileCompletion);

//Route to toggle visible or not visible user profile
router.patch("/toggle-visibility", userController.toggleVisibility);

// Route to set profile visibility
router.patch("/set-profile-visibility", userController.setProfileVisibility);

// Route to unhide profile manually
router.patch("/unhide-profile", userController.unhideProfile);

module.exports = router;
