const mongoose = require("mongoose");
const dotenv = require("dotenv");
const http = require("http");
const socketIo = require("socket.io");

process.on("uncaughtException", (err) => {
  console.log("UNCAUGHT EXCEPTION! 😓 Shutting down...");
  console.log(err.name, err.message);
  process.exit(1);
});

dotenv.config({ path: "./config.env" });
const app = require("./app");
const { setSocketInstance } = require("./controllers/connectionController");

// Socket.IO Setup
const server = http.createServer(app);
const io = socketIo(server);

// Set the socket instance for handling real-time events
setSocketInstance(io);

// MongoDB connection setup
const DB = process.env.DATABASE.replace(
  "<db_password>",
  process.env.DATABASE_PASSWORD
);

// Remove deprecated options
mongoose
  .connect(DB)
  .then(() => console.log("DB Connection Successful!"))
  .catch((err) => {
    console.log("MongoDB connection error:", err);
    process.exit(1); // Exit process on connection error
  });

const port = process.env.PORT || 3000;

server.listen(port, () => {
  console.log(`App is running on port ${port}...`);
});

// Handle unhandled promise rejections
process.on("unhandledRejection", (err) => {
  console.log("UNHANDLED REJECTION! 💥 Shutting down...");
  console.log(err.name, err.message);
  server.close(() => {
    process.exit(1);
  });
});

// Handle SIGTERM (graceful shutdown)
process.on("SIGTERM", () => {
  console.log("👋 SIGTERM RECEIVED. Shutting down gracefully");
  mongoose.connection.close(() => {
    console.log("MongoDB connection closed.");
    server.close(() => {
      console.log("💥 Process terminated!");
    });
  });
});
